@@ -7,6 +7,8 @@ class SatnogNetworkClient(SatnogClient):
     def __init__(self):
         SatnogClient.__init__(self)
         self._url = self.config['DEFAULT']['NETWORK_API_URL']
+        if "SATNOGS_NETWORK_API_URL" in os.environ:
+            self._url = os.environ['SATNOGS_NETWORK_API_URL']
 
     def get(self, url, params=None):
         return requests.get(url, params=params, proxies=self.proxies)
